@@ -1,5 +1,5 @@
 /*  $Id$
-    BurgerSpaceEngine.h
+    BurgerSpaceEngine.h - Main engine
 
     burgerspace - A hamburger-smashing video game.
     Copyright (C) 2001 Pierre Sarrazin <sarrazip@iname.com>
@@ -20,14 +20,14 @@
     02111-1307, USA.
 */
 
-#ifndef H_BurgerSpaceEngine
-#define H_BurgerSpaceEngine
+#ifndef _H_BurgerSpaceEngine
+#define _H_BurgerSpaceEngine
 
 #include "IngredientGroup.h"
 #include "IngredientSprite.h"
 
-#include "GameEngine.h"
-#include "Sprite.h"
+#include <gengameng/GameEngine.h>
+#include <gengameng/Sprite.h>
 
 #include <string>
 
@@ -48,16 +48,19 @@ public:
     enum { RIGHT, UP, LEFT, DOWN };
     /*	Possible directions of movement, in trigonometric order.
 	This enumeration is garanteed to start at zero.
-	The order of the constants is guarateed, so they are 0, 1, 2, 3.
+	The order of the constants is guaranteed, so they are 0, 1, 2, 3.
     */
 
-    BurgerSpaceEngine(int initLevelNumber) throw(int);
+    BurgerSpaceEngine(const string &windowManagerCaption, int initLevelNumber)
+							    throw(int, string);
     /*  See base class.
 
+	'windowManagerCaption' must contain the title to give to the window.
+
 	The game will start at level 'initLevelNumber'.
 	This must be a positive integer.
 
-	Throws an integer code if an error occurs.
+	Throws a string or an integer code if an error occurs.
     */
 
     virtual ~BurgerSpaceEngine();
@@ -72,15 +75,6 @@ public:
     /*  Inherited.
     */
 
-protected:
-
-    // Inherited:
-    bool animatePlayer();
-    void animateAutomaticCharacters();
-    void detectCollisions();
-    void restoreBackground();
-    void drawSprites();
-
 private:
 
     ///////////////////////////////////////////////////////////////////////////
@@ -110,6 +104,19 @@ private:
 	NUM_SUPPORTED_KEYS
     };
 
+
+    struct IntPair
+    {
+	int first, second;
+    };
+
+    
+    struct IntQuad
+    {
+	int first, second, third, fourth;
+    };
+
+
     class Level
     {
     public:
@@ -125,16 +132,13 @@ private:
 	int  getLevelNo() const;
 	void setTileMatrixEntry(int colNo, int rowNo,
 				XPM xpm, Pixmap pixmap);
-	bool *getDirtMatrixRow(int rowNo);
 	Pixmap *getTileMatrixRow(int rowNo);
 	XPM getXPMAtPixel(Couple pos) const;
-	void takeSpriteDirt(const Sprite &s);
 
     private:
 	int levelNo;
 	XPM *xpmMatrix;   // vector of XPM pointers
 	Pixmap *tileMatrix;  // vector of X11 pixmaps
-	bool *dirtMatrix;    // true means dirty
     };
 
     class IngInit
@@ -143,24 +147,17 @@ private:
 	enum IngType
 	{
 	    BOTTOM_BUN, MEAT, LETTUCE, RED_STUFF, YELLOW_STUFF, TOP_BUN
+
+	    /*	The red stuff is a slice of tomato, and the yellow stuff
+		is cheese.  This was not known at the time when this
+		enumeration was defined...
+	    */
 	};
 
 	int xInitTile, yInitTile, yTargetTile, rank;
 	IngType type;
     };
 
-    
-    struct IntPair
-    {
-	int first, second;
-    };
-
-    
-    struct IntQuad
-    {
-	int first, second, third, fourth;
-    };
-
 
     ///////////////////////////////////////////////////////////////////////////
     //
@@ -203,6 +200,7 @@ private:
 
     /*  PLAYER:
     */
+    bool userControlledPlayer;
     Couple initPlayerPos;  // initial player position in a level
     PixmapArray playerPA;
     Sprite *playerSprite;
@@ -219,11 +217,9 @@ private:
 		// 0 means none
 
     PixmapArray eggPA;
-    SpriteList  eggSprites;
     PixmapArray hotdogPA;
-    SpriteList  hotdogSprites;
     PixmapArray picklePA;
-    SpriteList  pickleSprites;
+    SpriteList  enemySprites;
 
 
     /*  INGREDIENTS:
@@ -286,9 +282,6 @@ private:
     Couple levelNoAreaPos;
     Couple levelNoAreaSize;
 
-    Couple messagePos;  // position of text messages to the user
-
-
     Level theCurrentLevel;
 
 
@@ -297,12 +290,27 @@ private:
     //  IMPLEMENTATION FUNCTIONS
     //
     //
+    bool isPepperRequested() const;
+    void chooseDirectionAmongMany(bool directions[4]) const;
+    int  chooseDirectionTowardTarget(
+			    Couple startPos, Couple targetPos, int speedFactor,
+			    const bool allowedDirections[4]) const;
+    void avoidEnemies(bool desiredDirs[4]) const;
+    void getPlayerDesiredDirections(bool desiredDirs[4]) const;
+
+    bool animatePlayer();
+    void animateAutomaticCharacters();
+    void detectCollisions();
+    void restoreBackground();
+    void drawSprites();
+
     void putSprite(const Sprite &s);
     void showInstructions();
     void initGameParameters();
     void initNextLevel(int levelNo = 0) throw(int);
     void startNewLife();
     void animateTemporarySprites(SpriteList &slist) const;
+    void givePlayerPepper();
     void makePlayerWin();
     void makePlayerDie();
     void releaseAllCarriedEnemies();
@@ -315,10 +323,8 @@ private:
     void loadPixmaps() throw(PixmapLoadError);
     void loadLevel(int levelNo) throw(string);
     void displayErrorMessage(const string &msg) throw();
-    int  initializeGraphicsContexts() throw();
     void initializeSprites() throw(PixmapLoadError);
     void initializeMisc() throw(string);
-    //void readKeyboardCommands();
     void killSpritesInList(SpriteList &sl);
     IngredientGroup *findIngredientGroupRightBelow(
 					const IngredientGroup &upperGroup);
@@ -329,7 +335,7 @@ private:
     size_t carryEnemiesInList(IngredientGroup &g, SpriteList &slist);
     size_t releaseCarriedEnemies(IngredientGroup &g);
     void createScoreSprites(long n, Couple center);
-    void moveEnemyList(SpriteList &slist, int speedFactor, long score);
+    void moveEnemyList(SpriteList &slist, int speedFactor);
     Couple getDistanceToPerfectPos(const Sprite &s) const;
     Couple determineAllowedDirections(const Sprite &s,
 				    int speedFactor, int tolerance,
@@ -347,6 +353,7 @@ private:
     void initTimeForTreat();
     void displayPauseMessage(bool display);
     void displayStartMessage(bool display);
+    void displayMessage(const char *msg);
 
 
     /*	Forbidden operations:
@@ -356,4 +363,4 @@ private:
 };
 
 
-#endif  /* H_BurgerSpaceEngine */
+#endif  /* _H_BurgerSpaceEngine */
