@@ -1,5 +1,5 @@
 /*  $Id$
-    EnemySprite.h
+    EnemySprite.h - Sprite that represents an enemy of the player.
 
     burgerspace - A hamburger-smashing video game.
     Copyright (C) 2001 Pierre Sarrazin <sarrazip@iname.com>
@@ -23,7 +23,7 @@
 #ifndef _H_EnemySprite
 #define _H_EnemySprite
 
-#include "Sprite.h"
+#include <gengameng/Sprite.h>
 
 class IngredientGroup;
 
