@@ -1,5 +1,5 @@
 /*  $Id$
-    IngredientGroup.h
+    IngredientGroup.h - Group of sprites representing an "ingredient"
 
     burgerspace - A hamburger-smashing video game.
     Copyright (C) 2001 Pierre Sarrazin <sarrazip@iname.com>
@@ -23,7 +23,7 @@
 #ifndef _H_IngredientGroup
 #define _H_IngredientGroup
 
-#include "Sprite.h"
+#include <gengameng/Sprite.h>
 
 #include <assert.h>
 #include <vector>
